.. workspace-tools documentation master file, created by
   sphinx-quickstart on Fri Dec 26 01:16:43 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to workspace-tools's documentation!
===========================================

.. toctree::
   :maxdepth: 2

   README
   commands

API Documentation
=================

.. toctree::
   :maxdepth: 2

   api/controller
   api/commands
   api/config
   api/scm
   api/utils

Change Log
=================

.. toctree::
   :maxdepth: 1

   CHANGELOG

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

